@@ -1,11 +1,8 @@
-#ifndef _GTKSOURCEVIEWMM_H
-#define _GTKSOURCEVIEWMM_H
-
-/* sourceviewmm.h
+/* gtksourceviewmm.h
  *
  * Based on gtksourceviewmm by Jae Jang
  * Copyright (C) 2005 Rob Page
- * Copyright (C) 2010 Krzesimir Nowak
+ * Copyright (C) 2010, 2011 Krzesimir Nowak
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -79,59 +76,63 @@
  *
  * <ul>
  * <li>Stuff marked as deprecated was removed of course.</li>
- * <li>"source-mark-updated" signal in Gsv::SourceBuffer now takes Gtk::TextMark
- * instead of SourceMark.</li>
- * <li>Vfuncs in Gsv::SourceCompletionProposal, Gsv::SourceCompletionProvider
- * and Gsv::SourceUndoManager are now private. They shouldn't be called directly
+ * <li>Removed Source prefix from all types, SOURCE_ prefix from all enum value
+ * names and source prefix from all file names. There is a helper script called
+ * source_truncate.pl in git repository in codegen directory to aid programmer
+ * in boring task of renaming everything.</li>
+ * <li>"source-mark-updated" signal in Gsv::Buffer now takes Gtk::TextMark
+ * instead of Mark.</li>
+ * <li>Vfuncs in Gsv::CompletionProposal, Gsv::CompletionProvider
+ * and Gsv::UndoManager are now private. They shouldn't be called directly
  * anyway - there are respective methods for this.</li>
  * <li>Some methods now takes std::string instead of Glib::ustring. These are:
  * <ul>
- * <li>Gsv::SourceLanguageManager::get_search_path()</li>
- * <li>Gsv::SourceLanguageManager::set_search_path()</li>
- * <li>Gsv::SourceLanguageManager::get_language_ids()</li>
- * <li>Gsv::SourceLanguageManager::get_language()</li>
- * <li>Gsv::SourceLanguageManager::guess_language()</li>
- * <li>Gsv::SourceStyleSchemeManager::set_search_path()</li>
- * <li>Gsv::SourceStyleSchemeManager::get_search_path()</li>
- * <li>Gsv::SourceStyleSchemeManager::append_search_path()</li>
- * <li>Gsv::SourceStyleSchemeManager::prepend_search_path()</li>
- * <li>Gsv::SourceStyleSchemeManager::get_scheme()</li>
- * <li>Gsv::SourceStyleSchemeManager::get_scheme_ids()</li>
+ * <li>Gsv::LanguageManager::get_search_path()</li>
+ * <li>Gsv::LanguageManager::set_search_path()</li>
+ * <li>Gsv::LanguageManager::get_language_ids()</li>
+ * <li>Gsv::LanguageManager::get_language()</li>
+ * <li>Gsv::LanguageManager::guess_language()</li>
+ * <li>Gsv::StyleSchemeManager::set_search_path()</li>
+ * <li>Gsv::StyleSchemeManager::get_search_path()</li>
+ * <li>Gsv::StyleSchemeManager::append_search_path()</li>
+ * <li>Gsv::StyleSchemeManager::prepend_search_path()</li>
+ * <li>Gsv::StyleSchemeManager::get_scheme()</li>
+ * <li>Gsv::StyleSchemeManager::get_scheme_ids()</li>
  * </ul></li>
- * <li>Gsv::SourceMark's constructor with category and name has parameter order
+ * <li>Gsv::Mark's constructor with category and name has parameter order
  * the same as C gtk_source_mark_new(). Previously parameter order was reversed,
  * because name parameter could be omitted - it has a default value of empty
- * string, which was interpreted as creating anonymous Gsv::SourceMark. Now
+ * string, which was interpreted as creating anonymous Gsv::Mark. Now
  * there is separate constructor for creating anonymous SourceMarks. If there
  * was:
  * @code
- * Glib::RefPtr<Gsv::SourceMark> sm (Gsv::SourceMark::create ("category", "name"));
+ * Glib::RefPtr<Gsv::Mark> sm (Gsv::Mark::create ("category", "name"));
  * @endcode
  * Now should be:
  * @code
- * Glib::RefPtr<Gsv::SourceMark> sm (Gsv::SourceMark::create ("name", "category"));
+ * Glib::RefPtr<Gsv::Mark> sm (Gsv::Mark::create ("name", "category"));
  * @endcode
  * If there was:
  * @code
- * Glib::RefPtr<Gsv::SourceMark> sm (Gsv::SourceMark::create ("category"));
+ * Glib::RefPtr<Gsv::Mark> sm (Gsv::Mark::create ("category"));
  * @endcode
  * Nothing needs to be changed. If there was:
  * @code
- * Glib::RefPtr<Gsv::SourceMark> sm (Gsv::SourceMark::create ("category", ""));
+ * Glib::RefPtr<Gsv::Mark> sm (Gsv::Mark::create ("category", ""));
  * @endcode
  * Now should be:
  * @code
- * Glib::RefPtr<Gsv::SourceMark> sm (Gsv::SourceMark::create ("category"));
+ * Glib::RefPtr<Gsv::Mark> sm (Gsv::Mark::create ("category"));
  * @endcode
  * </li>
- * <li>If there is a code that somehow depended on Gsv::SourceStyleScheme being
+ * <li>If there is a code that somehow depended on Gsv::StyleScheme being
  * a Glib::Interface, then this code is wrong, because it should always be
  * a Glib::Object.</li>
  * <li>SourceIter is gone - all its features are now supported by Gtk::TextIter.
  * </li>
- * <li>Gsv::SourceCompletion is now a Glib::Object, not Gtk::Object. So it
- * should be used as Glib::RefPtr<Gsv::SourceCompletion> instead of plain
- * Gsv::SourceCompletion.</li>
+ * <li>Gsv::Completion is now a Glib::Object, not Gtk::Object. So it
+ * should be used as Glib::RefPtr<Gsv::Completion> instead of plain
+ * Gsv::Completion.</li>
  * <li>Namespace @b gtksourceview was renamed to @b Gsv. If there is a lot
  * of code using  @b gtksourceview namespace then a workaround would be creating
  * a backward compatibility header and including it a place included by affected
@@ -145,48 +146,55 @@
  * <li>Replaced Glib::*Handle<> with std::vector<> - that means that passing
  * std::list<> or std::deque<> is now not supported. Affected methods are:
  * <ul>
- * <li>Gsv::SourceBuffer::get_source_marks_at_line()</li>
- * <li>Gsv::SourceBuffer::get_source_marks_at_iter()</li>
- * <li>Gsv::SourceBuffer::get_context_classes_at_iter()</li>
- * <li>Gsv::SourceCompletion::get_providers()</li>
- * <li>Gsv::SourceCompletion::show()</li>
- * <li>Gsv::SourceCompletionContext::add_proposals()</li>
- * <li>Gsv::SourceLanguage::get_mime_types()</li>
- * <li>Gsv::SourceLanguage::get_globs()</li>
- * <li>Gsv::SourceLanguage::get_style_ids()</li>
- * <li>Gsv::SourceLanguageManager::get_search_path()</li>
- * <li>Gsv::SourceLanguageManager::set_search_path()</li>
- * <li>Gsv::SourceLanguageManager::get_language_ids()</li>
- * <li>Gsv::SourceStyleScheme::get_authors()</li>
- * <li>Gsv::SourceStyleSchemeManager::get_search_path()</li>
- * <li>Gsv::SourceStyleSchemeManager::set_search_path()</li>
- * <li>Gsv::SourceStyleSchemeManager::get_scheme_ids()</li>
+ * <li>Gsv::Buffer::get_source_marks_at_line()</li>
+ * <li>Gsv::Buffer::get_source_marks_at_iter()</li>
+ * <li>Gsv::Buffer::get_context_classes_at_iter()</li>
+ * <li>Gsv::Completion::get_providers()</li>
+ * <li>Gsv::Completion::show()</li>
+ * <li>Gsv::CompletionContext::add_proposals()</li>
+ * <li>Gsv::Language::get_mime_types()</li>
+ * <li>Gsv::Language::get_globs()</li>
+ * <li>Gsv::Language::get_style_ids()</li>
+ * <li>Gsv::LanguageManager::get_search_path()</li>
+ * <li>Gsv::LanguageManager::set_search_path()</li>
+ * <li>Gsv::LanguageManager::get_language_ids()</li>
+ * <li>Gsv::StyleScheme::get_authors()</li>
+ * <li>Gsv::StyleSchemeManager::get_search_path()</li>
+ * <li>Gsv::StyleSchemeManager::set_search_path()</li>
+ * <li>Gsv::StyleSchemeManager::get_scheme_ids()</li>
  * </ul></li>
  * </ul>
  */
 
+#ifndef _GTKSOURCEVIEWMM_H
+#define _GTKSOURCEVIEWMM_H
+
 #include <gtksourceviewmmconfig.h>
 #include <gtksourceviewmm/init.h>
-#include <gtksourceviewmm/sourcebuffer.h>
-#include <gtksourceviewmm/sourcecompletion.h>
-#include <gtksourceviewmm/sourcecompletionactivation.h>
-#include <gtksourceviewmm/sourcecompletioncontext.h>
-#include <gtksourceviewmm/sourcecompletioninfo.h>
-#include <gtksourceviewmm/sourcecompletionitem.h>
-#include <gtksourceviewmm/sourcecompletionproposal.h>
-#include <gtksourceviewmm/sourcecompletionprovider.h>
-#include <gtksourceviewmm/sourcecompletionwords.h>
-#include <gtksourceviewmm/sourcegutter.h>
-#include <gtksourceviewmm/sourcelanguage.h>
-#include <gtksourceviewmm/sourcelanguagemanager.h>
-#include <gtksourceviewmm/sourcemark.h>
-#include <gtksourceviewmm/sourcemarkup.h>
-#include <gtksourceviewmm/sourceprintcompositor.h>
-#include <gtksourceviewmm/sourcestyle.h>
-#include <gtksourceviewmm/sourcestylescheme.h>
-#include <gtksourceviewmm/sourcestyleschememanager.h>
-#include <gtksourceviewmm/sourceundomanager.h>
-#include <gtksourceviewmm/sourceview.h>
+#include <gtksourceviewmm/buffer.h>
+#include <gtksourceviewmm/completion.h>
+#include <gtksourceviewmm/completionactivation.h>
+#include <gtksourceviewmm/completioncontext.h>
+#include <gtksourceviewmm/completioninfo.h>
+#include <gtksourceviewmm/completionitem.h>
+#include <gtksourceviewmm/completionproposal.h>
+#include <gtksourceviewmm/completionprovider.h>
+#include <gtksourceviewmm/completionwords.h>
+#include <gtksourceviewmm/gutter.h>
+#include <gtksourceviewmm/gutterrenderer.h>
+#include <gtksourceviewmm/gutterrendererpixbuf.h>
+#include <gtksourceviewmm/gutterrenderertext.h>
+#include <gtksourceviewmm/language.h>
+#include <gtksourceviewmm/languagemanager.h>
+#include <gtksourceviewmm/mark.h>
+#include <gtksourceviewmm/markattributes.h>
+#include <gtksourceviewmm/markup.h>
+#include <gtksourceviewmm/printcompositor.h>
+#include <gtksourceviewmm/style.h>
+#include <gtksourceviewmm/stylescheme.h>
+#include <gtksourceviewmm/styleschememanager.h>
+#include <gtksourceviewmm/undomanager.h>
+#include <gtksourceviewmm/view.h>
 #include <gtksourceviewmm/wrap_init.h>
 
 #endif /* #ifndef _GTKSOURCEVIEWMM_H */
