@@ -1,12 +1,8 @@
 // -*- c++ -*-
-#ifndef _GTKSOURCEVIEWMM_INIT_H
-#define _GTKSOURCEVIEWMM_INIT_H
-
-#include "wrap_init.h"
-
 /* init.h
  *
  * Copyright (C) 2005-2006 The gtksourceviewmm development team
+ * Copyright (C) 2010, 2011 Krzesimir Nowak
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -22,12 +18,16 @@
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-/// \file
-/// \brief the library initialization routines
-namespace gtksourceview
+
+#ifndef _GTKSOURCEVIEWMM_INIT_H
+#define _GTKSOURCEVIEWMM_INIT_H
+
+namespace Gsv
 {
-    void init () ;
-}//end namespace gtksourceview
+  /** Initializes all type internals.
+   */
+  void init () ;
+} // namespace Gsv
 
 #endif //_GTKSOURCEVIEWMM_INIT_H
 
